==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sr/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "Шаблон '$1' је успешно снимљен.");
regGS("The template $1 is in use and can not be deleted.", "Шаблон $1 је у употреби и не може бити обрисан.");
regGS("Create new folder", "Направи нови фолдер");
regGS("Upload template", "Аплоудуј шаблон");
regGS("You do not have the right to create new folders.", "Немате право да правите нове фолдере");
regGS("A file or folder having the name $1 already exists", "Фајл или фолдер са именом $1 већ постоји");
regGS("You do not have the right to delete templates.", "Немате право да бришете шаблоне");
regGS("Are you sure you want to delete the folder $1 from $2?", "Да ли сте сигурни да желите да обришете фолдер $1 из $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Да ли сте сигурни да желите да обришете шаблон $1 из фолдера $2?");
regGS("Template $1 was deleted", "Шаблон $1 је обрисан");
regGS("Delete folder", "Обриши фолдер");
regGS("Folders", "Фолдери");
regGS("No folders.", "Нема фолдера");
regGS("Files", "Фајлови");
regGS("No templates.", "Нема шаблона");
regGS("File", "Фајл");
regGS("Create new template", "Креирај нови шаблон");
regGS("Duplicate template", "Дуплирај шаблон");
regGS("Edit template", "Уреди шаблон");
regGS("The template $1 could not be created.", "Шаблон $1 не може бити креиран");
regGS("Template $1 was changed", "Шаблон $1 је промењен");
regGS("Template $1 was duplicated into $2", "Шаблон $1 је дуплиран у $2");
regGS("Template charset", "Кодни распоред шаблона");
regGS("Select a language/character set", "Изабери језик/кодни распоред");
regGS("All languages", "Сви језици");
regGS("You do not have the right to modify templates.", "Немате право да мењате шаблоне.");
regGS("Invalid template file $1", "Погрешно име шаблона $1");
regGS("You do not have the right to create folders.", "Немате право да правите фолдере.");
regGS("You do not have the right to upload templates.", "Немате право да аплоудујете шаблоне.");
regGS("You do not have the right to create templates.", "Немате право да правите шаблоне.");
regGS("Duplicate file", "Дуплирај фајл");
regGS("Delete file", "Обриши фајл");
regGS("Please check if the user '$1' has permission to write in this directory.", "Проверите да ли корисник '$1'има овлашћења да уписује у овај директоријум.");
regGS("The folder has been deleted.", "Фолдер је избрисан");
regGS("The template has been deleted.", "Шаблон је избрисан");
regGS("The template could not be deleted.", "Шаблон не може бити избрисан");
regGS("Save", "Сними");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sr/templates.php <==
<?php 
regGS("Unable to create folder.", "Није могуће креирати фолдер");
regGS("Unable to $1 template.", "Није могуће $1 шаблон");
regGS("File cannot be read.", "Фајл $1 није читљив");
regGS("Template ID:", "ИД шаблона:");
regGS("Template ID", "ИД шаблона");
regGS("Template $1 no longer exists!", "Шаблон $1 више не постоји");
regGS("New template $1 created", "Креиран је нови шаблон $1");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "Ако је фајл који сте унели текстуални фајл, можете променити његов карактер сет помоћу падајућег менија");
regGS("Directory $1 was deleted", "Директоријум $1 је обрисан");
regGS("Directory $1 created.", "Директоријум $1 је креиран");
regGS("You must select a file to upload.", "Морате изабрати фајл који желите да аплоудујете");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "Фајл можете заменити једино другим фајлом истог типа. Оригинални фајл је типа '$1', а фајл који сте аплоудовали је типа '$2");
regGS("Unable to save the file '$1' to the path '$2'.", "'Није могуће снимити фајл '$1'на путању '$2'");
regGS("Replace file:", "Замени фајл");
regGS("Replace", "Замени");
regGS("File \"$1\" uploaded.", "Фајл '$1' је аплоудован");
regGS("File \"$1\" replaced.", "Фајл '$1' је замењен");
regGS("The folder name can't be '..' or '.'", "Име фолдера не може бити '..' или '.");
regGS("The template '$1' was saved successfully.", "Шаблон '$1' је успешно снимљен.");
regGS("The template $1 is in use and can not be deleted.", "Шаблон $1 је у употреби и не може бити обрисан.");
regGS("Create new folder", "Направи нови фолдер");
regGS("Upload template", "Аплоудуј шаблон");
regGS("You do not have the right to create new folders.", "Немате право да правите нове фолдере");
regGS("A file or folder having the name $1 already exists", "Фајл или фолдер са именом $1 већ постоји");
regGS("You do not have the right to delete templates.", "Немате право да бришете шаблоне");
regGS("Are you sure you want to delete the folder $1 from $2?", "Да ли сте сигурни да желите да обришете фолдер $1 из $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Да ли сте сигурни да желите да обришете шаблон $1 из фолдера $2?");
regGS("Template $1 was deleted", "Шаблон $1 је обрисан");
regGS("Delete folder", "Обриши фолдер");
regGS("Folders", "Фолдери");
regGS("No folders.", "Нема фолдера");
regGS("Files", "Фајлови");
regGS("No templates.", "Нема шаблона");
regGS("File", "Фајл");
regGS("Create new template", "Креирај нови шаблон");
regGS("Duplicate template", "Дуплирај шаблон");
regGS("Edit template", "Уреди шаблон");
regGS("The template $1 could not be created.", "Шаблон $1 не може бити креиран");
regGS("Template $1 was changed", "Шаблон $1 је промењен");
regGS("Template $1 was duplicated into $2", "Шаблон $1 је дуплиран у $2");
regGS("Template charset", "Кодни распоред шаблона");
regGS("Select a language/character set", "Изабери језик/кодни распоред");
regGS("All languages", "Сви језици");
regGS("You do not have the right to modify templates.", "Немате право да мењате шаблоне.");
regGS("Invalid template file $1", "Погрешно име шаблона $1");
regGS("You do not have the right to create folders.", "Немате право да правите фолдере.");
regGS("You do not have the right to upload templates.", "Немате право да аплоудујете шаблоне.");
regGS("You do not have the right to create templates.", "Немате право да правите шаблоне.");
regGS("Duplicate file", "Дуплирај фајл");
regGS("Delete file", "Обриши фајл");
regGS("Please check if the user '$1' has permission to write in this directory.", "Проверите да ли корисник '$1'има овлашћења да уписује у овај директоријум.");
regGS("The folder has been deleted.", "Фолдер је избрисан");
regGS("The template has been deleted.", "Шаблон је избрисан");
regGS("The template could not be deleted.", "Шаблон не може бити избрисан");
regGS("Save", "Сними");
?>
